# From JSON

A JSON output file generated by tuxsuite can be used in order to fetch
the results. `tuxsuite results` sub-command will automatically
identify the JSON format and fetch the results, whether it is
build/test/plan.

```shell
tuxsuite results --from-json /tmp/test_result.json
```

The results obtained by passing `--from-json` can be captured to a
JSON file once again, as follows.

```shell
tuxsuite results --from-json /tmp/test_result.json --json-out /tmp/result.json
```
